Package 'r2zotero'

Title: Send Suggested R Package Citations Directly to Zotero
Description: Facilitates the citation of R packages by importing citations from 'CITATION' file directly to a local Zotero library using the Zotero Web API.
Authors: Ethan Bass [aut, cre] (ORCID: <https://orcid.org/0000-0002-6175-6739>)
Maintainer: Ethan Bass <[email protected]>
License: MIT + file LICENSE
Version: 0.1.0
Built: 2026-05-31 10:09:56 UTC
Source: https://github.com/ethanbass/r2zotero

Help Index


r -> Zotero

Description

Send citations from the citation function directly to Zotero library through the Zotero JSON web API.

Usage

r2zotero(pkg = "base", manual_as_document = FALSE, verbose = TRUE)

Arguments

pkg

Package to cite.

manual_as_document

Whether to export MANUAL bibtex entries as a document rather than software. Defaults to FALSE.

verbose

Whether to print verbose output to console. Defaults to TRUE.

Details

As with Zotero browser plugins, the Zotero desktop application must be running for the function to work.

Value

No return value. Function is called for its side effects.

Side effects

Imports the citations generated by citation to a local Zotero library.

Author(s)

Ethan Bass

Examples

## send package references to Zotero
r2zotero("foreign")
r2zotero("lattice")