| Title: | Send Suggested R Package Citations Directly to Zotero |
|---|---|
| Description: | Facilitates the citation of R packages by importing citations from 'CITATION' file directly to a local Zotero library using the Zotero Web API. |
| Authors: | Ethan Bass [aut, cre] (ORCID: <https://orcid.org/0000-0002-6175-6739>) |
| Maintainer: | Ethan Bass <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-05-31 10:09:56 UTC |
| Source: | https://github.com/ethanbass/r2zotero |
Send citations from the citation function directly to Zotero
library through the Zotero JSON web API.
r2zotero(pkg = "base", manual_as_document = FALSE, verbose = TRUE)r2zotero(pkg = "base", manual_as_document = FALSE, verbose = TRUE)
pkg |
Package to cite. |
manual_as_document |
Whether to export |
verbose |
Whether to print verbose output to console. Defaults to
|
As with Zotero browser plugins, the Zotero desktop application must be running for the function to work.
No return value. Function is called for its side effects.
Imports the citations generated by citation to a local Zotero library.
Ethan Bass
## send package references to Zotero r2zotero("foreign") r2zotero("lattice")## send package references to Zotero r2zotero("foreign") r2zotero("lattice")